(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('react'), require('@apollo/client'), require('graphql-tools'), require('@graphql-tools/mock'), require('@apollo/client/link/schema'), require('@apollo/client/link/error'), require('fs'), require('graphql'), require('isomorphic-unfetch'), require('@graphql-tools/wrap')) :
  typeof define === 'function' && define.amd ? define(['exports', 'react', '@apollo/client', 'graphql-tools', '@graphql-tools/mock', '@apollo/client/link/schema', '@apollo/client/link/error', 'fs', 'graphql', 'isomorphic-unfetch', '@graphql-tools/wrap'], factory) :
  (global = global || self, factory(global['apollo-mocked-provider'] = {}, global.React, global.client, global.graphqlTools, global.mock, global.schema, global.error, global.fs, global.graphql, global.fetch, global.wrap));
}(this, function (exports, React, client, graphqlTools, mock, schema, error, fs, graphql, fetch, wrap) { 'use strict';

  var React__default = 'default' in React ? React['default'] : React;
  fetch = fetch && fetch.hasOwnProperty('default') ? fetch['default'] : fetch;

  var createApolloErrorProvider = function createApolloErrorProvider(_temp) {
    var _ref = _temp === void 0 ? {} : _temp,
        globalCache = _ref.cache;

    return function (_ref2) {
      var graphQLErrors = _ref2.graphQLErrors,
          cache = _ref2.cache,
          children = _ref2.children;
      // This is just a link that swallows all operations and returns the same thing
      // for every request: The specified error.
      var link = new client.ApolloLink(function () {
        return new client.Observable(function (observer) {
          observer.next({
            errors: graphQLErrors || [{
              message: 'Unspecified error from ErrorProvider.'
            }]
          });
          observer.complete();
        });
      });
      var client$1 = new client.ApolloClient({
        link: link,
        cache: cache || globalCache || new client.InMemoryCache()
      });
      return React.createElement(client.ApolloProvider, {
        client: client$1
      }, children);
    };
  };

  var createApolloLoadingProvider = function createApolloLoadingProvider(_temp) {
    var _ref = _temp === void 0 ? {} : _temp,
        globalCache = _ref.cache;

    return function (_ref2) {
      var children = _ref2.children,
          cache = _ref2.cache;
      var link = new client.ApolloLink(function () {
        return new client.Observable(function () {});
      });
      var client$1 = new client.ApolloClient({
        link: link,
        cache: cache || globalCache || new client.InMemoryCache()
      });
      return React.createElement(client.ApolloProvider, {
        client: client$1
      }, children);
    };
  };

  var createApolloMockedProvider = function createApolloMockedProvider(typeDefs, _temp) {
    var _ref = _temp === void 0 ? {} : _temp,
        globalCache = _ref.cache,
        links = _ref.links;

    return function (_ref2) {
      var _ref2$customResolvers = _ref2.customResolvers,
          customResolvers = _ref2$customResolvers === void 0 ? {} : _ref2$customResolvers,
          componentCache = _ref2.cache,
          children = _ref2.children;
      // const mocks = mergeResolvers(globalMocks, props.customResolvers);
      var baseSchema = graphqlTools.makeExecutableSchema({
        typeDefs: typeDefs,
        resolverValidationOptions: {
          requireResolversForResolveType: false
        }
      });
      var schema$1 = mock.addMocksToSchema({
        schema: baseSchema,
        mocks: customResolvers
      });
      var cache = componentCache || globalCache || new client.InMemoryCache();
      var customLinks = links ? links({
        cache: cache,
        schema: schema$1
      }) : [];
      var client$1 = new client.ApolloClient({
        link: client.ApolloLink.from([error.onError(function () {})].concat(customLinks, [new schema.SchemaLink({
          schema: schema$1
        })])),
        cache: cache,
        defaultOptions: {
          mutate: {
            errorPolicy: 'all'
          }
        }
      });
      return React__default.createElement(client.ApolloProvider, {
        client: client$1
      }, children);
    };
  };

  var fetchTypeDefs = function fetchTypeDefs(_ref) {
    var _ref$uri = _ref.uri,
        uri = _ref$uri === void 0 ? 'http://localhost:4000/graphql' : _ref$uri,
        _ref$typescript = _ref.typescript,
        typescript = _ref$typescript === void 0 ? true : _ref$typescript,
        _ref$path = _ref.path,
        path = _ref$path === void 0 ? process.cwd() + "/typeDefs." + (typescript ? 'ts' : 'js') : _ref$path;

    try {
      console.log('writing typeDefs to: ', path);

      var executor = function executor(_ref2) {
        var document = _ref2.document,
            variables = _ref2.variables;

        try {
          var query = graphql.print(document);
          return Promise.resolve(fetch(uri, {
            method: 'POST',
            headers: {
              'Content-Type': 'application/json'
            },
            body: JSON.stringify({
              query: query,
              variables: variables
            })
          })).then(function (fetchResult) {
            return fetchResult.json();
          });
        } catch (e) {
          return Promise.reject(e);
        }
      };

      return Promise.resolve(wrap.introspectSchema(executor)).then(function (schema) {
        fs.writeFileSync(path, "export const typeDefs = `\n" + graphql.printSchema(schema).replace(/`/g, '\\`') + "`");
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };

  exports.createApolloErrorProvider = createApolloErrorProvider;
  exports.createApolloLoadingProvider = createApolloLoadingProvider;
  exports.createApolloMockedProvider = createApolloMockedProvider;
  exports.fetchTypeDefs = fetchTypeDefs;

}));
//# sourceMappingURL=apollo-mocked-provider.umd.development.js.map
